Python 6502 Emulator
====================

|Tests|

A MOS 6502 Emulator intended to be used from within other programs. All
opcodes, included the undocumented illegal opcodes are implemented.

.. image:: https://github.com/YOU/YOUR-PROJECT/workflows/CI/badge.svg?branch=master
     :target: https://github.com/YOU/YOUR-PROJECT/actions?workflow=CI
     :alt: CI Status

.. |Tests| image:: https://github.com/TXC/py65emu/actions/workflows/run-tests.yml/badge.svg?branch=master
   :target: https://github.com/TXC/py65emu/actions/workflows/run-tests.yml
